function a = vynos(P,R,n);
% Autor: Stanislav Tvrz
% function a=vynos(P,R,n);
% funkce pocita: 
%        vektory strednich hodnot celkovych vynosu po jednom az po n obdobich 
%        znazorni prubehy vektoru strednich hodnot pro jednotlive stavy 
%        v zavislosti na poctu obdobi
% vstupni parametry:
% P - matice prechodu
% R -  matice vynosu
% n - pocet obdobi

%clc;

disp('kontrola - matice prechodu P')
P
disp(' ')
disp('kontrola - matice vynosu R')
R
disp(' ')

vel=size(P);
v=zeros(vel(1),n+1);
q=diag(P*R');
for i=2:n+1
    v(:,i)=q+P*v(:,i-1);
end
cas=0:n;
vysledek=[cas;v];
disp('sloupcove vektory strednich hodnot celkovych vynosu po n krocich')
disp(num2str(vysledek))
disp('pozn: na prvnim radku hodnoty n')

%generovani popisu stavu
max_ind=size(num2str(vel(1)),2);
legenda=zeros(vel(1),5+max_ind);
for i=1:vel(1)
    legenda(i,1:5+size(num2str(i),2))=[['stav '],num2str(i)];
end       
legenda=char(legenda);

%graf celkovych vynosu
figure
plot([0:n],v);
legend(legenda)
end